@@ -1,5 +1,5 @@
-#!/usr/bin/env rspec
-
+# frozen_string_literal: true
+#
 # Copyright, 2016, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -22,12 +22,10 @@
 
 require 'http/accept/quoted_string'
 
-module HTTP::Accept::QuotedStringSpec
-	describe HTTP::Accept::MediaTypes do
-		it "should ignore linear whitespace" do
-			quoted_string = HTTP::Accept::QuotedString.unquote(%Q{"Hello\r\n  World"})
-			
-			expect(quoted_string).to be == "Hello World"
-		end
+RSpec.describe HTTP::Accept::MediaTypes do
+	it "should ignore linear whitespace" do
+		quoted_string = HTTP::Accept::QuotedString.unquote(%Q{"Hello\r\n  World"})
+		
+		expect(quoted_string).to be == "Hello World"
 	end
-end
\ No newline at end of file
+end
